package cz.muni.fi.pb162.cv10;
import java.util.*;

/**
 * Represents a record in an address book.
 * 
 * @author Zuzana Neverilova
 * @version 2010-06-12
 */
public class Address
{
    private String nick;
    private Set<Number> numbers = new HashSet<Number>();
    
    public Address(String nick, String ... phones) throws NotAPhoneNumberException{
        if (nick == null) 
            throw new NullPointerException("Nick name cannot be null");
        this.nick = nick;
        add(phones);
    }
    
    public final Address add(String ... phones) throws NotAPhoneNumberException{
        Set<Number> s = new HashSet<Number>();
        for (String p: phones){
            Number n = new PhoneNumber(p);
            if (!n.isValid())
                throw new NotAPhoneNumberException("'"+n+"' is not a valid phone number");
            s.add(n);
        }
        numbers.addAll(s);
        return this;
    }

    public String toString(){
        String s="";
        for (Number n: numbers){
            s+=n.toString()+":";
        }
        return nick+"*"+s;
    }
}
